@@ -61,7 +61,7 @@ def get_one(db_client, query_string):
             return None
 
         else:
-            print("GET ONE RESULT: " + json.dumps(result))
+            #print("GET ONE RESULT: " + json.dumps(result))
             return result
 
     except (Exception, pg8000.DatabaseError) as error:
