@@ -207,6 +207,48 @@ def make_update_string(object, table, key, key_value):
                 else:
                     value = json.dumps(value).replace("[", "{").replace("]", "}")
                     string = string + name + " = '" + value + "', "
+
+            else:
+                string = string + name + " = '" + value + "', "
+
+    update_string = (
+            "UPDATE " + table + " SET " + string[:-2]
+            + " WHERE " + key + " = '" + key_value + "'"
+    )
+
+    update_string = update_string.replace("'", "\'")
+    print("UPDATE STRING: " + update_string)
+
+    return update_string
+
+
+def make_update_string_v2(object, table, key, key_value):
+    string = ""
+
+    for name, value in object.items():
+        if name != key:
+            if type(value) == str:
+                value = value.replace("'", "''")
+
+            if type(value) == dict:
+                if value == {} or value == "":
+                    string = string + name + " = '{}', "
+                else:
+                    string = string + name + " = '" + json.dumps(value) + "', "
+
+            elif type(value) is list:
+
+                if is_list_of_jsons(value) is True and value != []:
+                    value = json.dumps(value).replace("[", "{'").replace("]", "'}")
+                    string = string + " " + value + ", "
+
+                else:
+                    value = json.dumps(value).replace("[", "{").replace("]", "}")
+                    string = string + name + " = '" + value + "', "
+
+            elif value is None:
+                string = string + name + " =  NULL, "
+
             else:
                 string = string + name + " = '" + value + "', "
 
